"use strict";

Object.defineProperty(exports, "__esModule", {
  value: true
});
exports.MobileInteractionPlugin = void 0;

var _tslib = require("tslib");

var _g = require("@antv/g");

var _manaSyringe = require("mana-syringe");

/**
 * listen to mouse/touch/pointer events on DOM wrapper, trigger pointer events
 */
var MobileInteractionPlugin =
/** @class */
function () {
  function MobileInteractionPlugin() {}

  MobileInteractionPlugin_1 = MobileInteractionPlugin;

  MobileInteractionPlugin.prototype.apply = function (renderingService) {
    var _this = this; // 获取小程序上下文


    var canvasEl = this.contextService.getDomElement();

    var onPointerDown = function onPointerDown(ev) {
      renderingService.hooks.pointerDown.call(ev);
    };

    var onPointerUp = function onPointerUp(ev) {
      renderingService.hooks.pointerUp.call(ev);
    };

    var onPointerMove = function onPointerMove(ev) {
      // 触发 G 定义的标准 pointerMove 事件
      renderingService.hooks.pointerMove.call(ev);
    };

    var onPointerOver = function onPointerOver(ev) {
      renderingService.hooks.pointerOver.call(ev);
    };

    var onPointerOut = function onPointerOut(ev) {
      renderingService.hooks.pointerOut.call(ev);
    };

    var onPointerCancel = function onPointerCancel(ev) {
      renderingService.hooks.pointerCancel.call(ev);
    };

    renderingService.hooks.init.tapPromise(MobileInteractionPlugin_1.tag, function () {
      return (0, _tslib.__awaiter)(_this, void 0, void 0, function () {
        return (0, _tslib.__generator)(this, function (_a) {
          // 基于小程序上下文的事件监听方式，绑定事件监听，可以参考下面基于 DOM 的方式
          canvasEl.addEventListener('touchstart', onPointerDown, true);
          canvasEl.addEventListener('touchend', onPointerUp, true);
          canvasEl.addEventListener('touchmove', onPointerMove, true);
          canvasEl.addEventListener('touchcancel', onPointerCancel, true);
          canvasEl.addEventListener('mousemove', onPointerMove, true);
          canvasEl.addEventListener('mousedown', onPointerDown, true);
          canvasEl.addEventListener('mouseout', onPointerOut, true);
          canvasEl.addEventListener('mouseover', onPointerOver, true);
          canvasEl.addEventListener('mouseup', onPointerUp, true);
          return [2
          /*return*/
          ];
        });
      });
    });
    renderingService.hooks.destroy.tap(MobileInteractionPlugin_1.tag, function () {
      // 基于小程序上下文的事件监听方式，移除事件监听
      canvasEl.removeEventListener('touchstart', onPointerDown, true);
      canvasEl.removeEventListener('touchend', onPointerUp, true);
      canvasEl.removeEventListener('touchmove', onPointerMove, true);
      canvasEl.removeEventListener('touchcancel', onPointerCancel, true);
      canvasEl.removeEventListener('mousemove', onPointerMove, true);
      canvasEl.removeEventListener('mousedown', onPointerDown, true);
      canvasEl.removeEventListener('mouseout', onPointerOut, true);
      canvasEl.removeEventListener('mouseover', onPointerOver, true);
      canvasEl.removeEventListener('mouseup', onPointerUp, true);
    });
  };

  var MobileInteractionPlugin_1;
  MobileInteractionPlugin.tag = 'MobileInteraction';
  (0, _tslib.__decorate)([(0, _manaSyringe.inject)(_g.ContextService), (0, _tslib.__metadata)("design:type", Object)], MobileInteractionPlugin.prototype, "contextService", void 0);
  MobileInteractionPlugin = MobileInteractionPlugin_1 = (0, _tslib.__decorate)([(0, _manaSyringe.singleton)({
    contrib: _g.RenderingPluginContribution
  })], MobileInteractionPlugin);
  return MobileInteractionPlugin;
}();

exports.MobileInteractionPlugin = MobileInteractionPlugin;